@@ -1,7 +1,7 @@
 
 import timeit
 from fiona import collection
-import ogr
+from osgeo import ogr
 
 PATH = 'docs/data/test_uk.shp'
 NAME = 'test_uk'
@@ -16,8 +16,8 @@ t = timeit.Timer(
     stmt=s,
     setup='from __main__ import collection, PATH, NAME'
     )
-print "Fiona (Cython)"
-print "%.2f usec/pass" % (1000000 * t.timeit(number=100)/100)
+print "Fiona 0.5"
+print "%.2f usec/pass" % (1000000 * t.timeit(number=1000)/1000)
 print
 
 # OGR
@@ -42,10 +42,10 @@ while 1:
     feature.Destroy()
 source.Destroy()
 """
-print "ogr.py (new bindings)"
+print "osgeo.ogr 1.7.2"
 t = timeit.Timer(
     stmt=s,
     setup='from __main__ import ogr, PATH, NAME'
     )
-print "%.2f usec/pass" % (1000000 * t.timeit(number=100)/100)
+print "%.2f usec/pass" % (1000000 * t.timeit(number=1000)/1000)
 
